@@ -1,6 +1,6 @@
 # Ebay.pm
 # by Martin Thurn
-# $Id: Ebay.pm,v 1.7 2001/07/30 18:05:35 mthurn Exp mthurn $
+# $Id: Ebay.pm,v 1.12 2002/04/22 14:29:29 mthurn Exp mthurn $
 
 =head1 NAME
 
@@ -46,10 +46,10 @@ Please tell the author if you find any!
 =head1 AUTHOR
 
 C<WWW::Search::Ebay> was written by Martin Thurn
-(MartinThurn@iname.com).
+(mthurn@cpan.org).
 
 C<WWW::Search::Ebay> is maintained by Martin Thurn
-(MartinThurn@iname.com).
+(mthurn@cpan.org).
 
 =head1 LEGALESE
 
@@ -59,6 +59,14 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 VERSION HISTORY
 
+=head2 2.07, 2001-12-20
+
+Restructured using parse_tree()
+
+=head2 2.06, 2001-12-20
+
+Handle new ebay.com output format
+
 =head2 2.01
 
 First publicly-released version.
@@ -73,13 +81,11 @@ package WWW::Search::Ebay;
 
 use Carp ();
 use Data::Dumper;  # for debugging only
-use HTML::Form;
-use HTML::TreeBuilder;
 use WWW::Search qw( generic_option strip_tags );
 require WWW::SearchResult;
 
-$VERSION = '2.06';
-$MAINTAINER = 'Martin Thurn <MartinThurn@iname.com>';
+$VERSION = '2.08';
+$MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 # private
 sub native_setup_search
@@ -95,7 +101,7 @@ sub native_setup_search
   # $DEFAULT_HITS_PER_PAGE = 30 if $self->{_debug};
   $self->{'_hits_per_page'} = $DEFAULT_HITS_PER_PAGE;
 
-  $self->{agent_e_mail} = 'MartinThurn@iname.com';
+  # $self->{agent_e_mail} = 'mthurn@cpan.org';
   $self->user_agent('non-robot');
 
   $self->{'_next_to_retrieve'} = 0;
@@ -137,40 +143,24 @@ sub native_setup_search
   } # native_setup_search
 
 
-# private
-sub native_retrieve_some
+sub preprocess_results_page
   {
-  my ($self) = @_;
-
-  # Fast exit if already done:
-  return undef unless defined($self->{_next_url});
-
-  # If this is not the first page of results, sleep so as to not overload the server:
-  $self->user_agent_delay if 1 < $self->{'_next_to_retrieve'};
-
-  # Get some results, adhering to the WWW::Search mechanism:
-  print STDERR " +   sending request (",$self->{_next_url},")\n" if $self->{'_debug'};
-  my $response = $self->http_request('GET', $self->{_next_url});
-  $self->{response} = $response;
-  unless ($response->is_success)
-    {
-    return undef;
-    } # unless
-
-  print STDERR " +   got response\n" if $self->{'_debug'};
-  my $sBaseURL = $self->{'_next_url'};
-  $self->{'_next_url'} = undef;
-
-  # Parse the output:
-  my $hits_found = 0;
-  my $tree = new HTML::TreeBuilder;
-  my $sPage = $response->content;
+  my $self = shift;
+  my $sPage = shift;
   # Ebay sends malformed HTML:
   my $iSubs = 0 + ($sPage =~ s!</FONT></TD></FONT></TD>!</FONT></TD>!gi);
-  # print STDERR " +   deleted $iSubs extraneous tags\n" if 1 < $self->{_debug};
-  $tree->parse($sPage);
-  $tree->eof;
+  print STDERR " +   deleted $iSubs extraneous tags\n" if 1 < $self->{_debug};
+  return $sPage;
+  } # preprocess_results_page
 
+
+# private
+sub parse_tree
+  {
+  my $self = shift;
+  my $tree = shift;
+
+  my $hits_found = 0;
   # The hit count is in a FONT tag:
   my @aoFONT = $tree->look_down('_tag', 'font');
  FONT:
@@ -183,7 +173,6 @@ sub native_retrieve_some
       last FONT;
       } # if
     } # foreach
-
   # The list of matching items is in a table.  The first column of the
   # table is nothing but icons; the second column is the good stuff.
   my @aoTD = $tree->look_down('_tag', 'td',
@@ -191,7 +180,12 @@ sub native_retrieve_some
                                      ($_[0]->as_HTML =~ m!ViewItem! )
                                      &&
                                      # Ignore thumbnails:
-                                     ($_[0]->as_HTML !~ m!\#DESC! )
+                                     ($_[0]->as_HTML !~ m!thumbs\.ebay\.com! )
+                                     &&
+                                     # Ignore other images:
+                                     ($_[0]->as_HTML !~ m!alt="Pic"!i )
+                                     &&
+                                     ($_[0]->as_HTML !~ m!alt="BuyItNow"!i )
                                     )
                                   }
                              );
@@ -199,8 +193,10 @@ sub native_retrieve_some
   foreach my $oTD (@aoTD)
     {
     my $sTD = $oTD->as_HTML;
+    # First FONT tag contains the url & title:
     my $oFONT = $oTD->look_down('_tag', 'font');
     next TD unless ref $oFONT;
+    # First A tag contains the url & title:
     my $oA = $oFONT->look_down('_tag', 'a');
     next TD unless ref $oA;
     my $sURL = $oA->attr('href');
@@ -267,11 +263,15 @@ sub native_retrieve_some
  TRY_NEXT:
   foreach my $oA (reverse @aoA)
     {
-    next unless ref $oA;
+    next TRY_NEXT unless ref $oA;
     print STDERR " +   try NEXT A ===", $oA->as_HTML, "===\n" if 1 < $self->{_debug};
+    my $href = $oA->attr('href');
+    next TRY_NEXT unless $href;
+    # If we get all the to the item list, there must be no next button:
+    last TRY_NEXT if $href =~ m!ViewItem!;
     if ($oA->as_text =~ m!Next\s+(>|&gt;)!i)
       {
-      $self->{_next_url} = $self->absurl($sBaseURL, $oA->attr('href'));
+      $self->{_next_url} = $self->absurl(undef, $href);
       print STDERR " +   got NEXT A ===", $self->{_next_url}, "===\n" if 1 < $self->{_debug};
       last TRY_NEXT;
       } # if
@@ -280,69 +280,9 @@ sub native_retrieve_some
   # All done with this page.
   $tree->delete;
   return $hits_found;
-  } # native_retrieve_some
+  } # parse_tree
 
 1;
 
 __END__
 
-Martin''s page download notes, 2001-04:
-
-http://search.ebay.com/search/search.dll?MfcISAPICommand=GetResult&ht=1&SortProperty=MetaEndSort&query=taco+bell+star+wars
-
-http://search.ebay.com/search/search.dll?MfcISAPICommand=GetResult&ht=1&ebaytag1=ebayreg&query=taco+bell+pog*&query2=taco+bell+pog*&search_option=1&exclude=&category0=&minPrice=&maxPrice=&ebaytag1code=0&st=0&SortProperty=MetaNewSort
-
-<TR>
-<TD align="center" valign="middle" width="12%">
-  <FONT size=3>
-  <A href="http://pages.ebay.com/help/basics/g-pic.html">
-  <IMG height=15 width=64 border=0 alt="[Picture!]" src="http://pics.ebay.com/aw/pics/lst/_p__64x15.gif">
-  </A>
-  </FONT>
-</TD>
-<TD valign="top" width="54%">
-  <A href="http://pages.ebay.com/help/basics/g-new.html">
-    <IMG height=15 width=16 border=0 alt="New!" src="http://pics.ebay.com/aw/pics/lst/new.gif">
-  </A>
-  <FONT size=3>
-    <A href="http://cgi.ebay.com/aw-cgi/eBayISAPI.dll?ViewItem&item=1050807630">
-      Star Wars: Boba Fett:When the fat lady Swings
-    </A>
-  </FONT>
-</TD>
-<TD nowrap align="right" valign="top" width="11%">
-  <FONT size=3>
-    <B>
-      <FONT size="-1" color="#666666">
-        EUR
-      </FONT> 5.50
-    </B>
-    <BR>
-    <I>
-      $4.95
-    </I>
-    </FONT>
-  </TD>
-  </FONT>
-</TD>
-<TD align="center" valign="top" width="5%">
-<FONT size=3>-
-</FONT>
-</TD>
-<TD align="right" valign="top" width="18%">
-<FONT size=3>Dec-20 01:54
-</FONT>
-</TD>
-</TR>
-</TABLE>
-<TABLE width="100%" cellpadding=4 border=0 cellspacing=0 bgcolor="#EFEFEF">
-
-=====
-
-<TABLE width="100%" cellpadding=4 border=0 cellspacing=0 bgcolor="#FFFFFF">
-<TR><TD align="center" valign="middle" width="12%"><FONT size=3>
-<A href="http://pages.ebay.com/help/basics/g-pic.html"><IMG height=15 width=64 border=0 alt="[Picture!]" src="http://pics.ebay.com/aw/pics/lst/_p__64x15.gif"></A>
-</FONT></TD><TD valign="top" width="54%"><A href="http://pages.ebay.com/help/basics/g-new.html"><IMG height=15 width=16 border=0 alt="New!" src="http://pics.ebay.com/aw/pics/lst/new.gif"></A>
-<FONT size=3><A href="http://cgi.ebay.com/aw-cgi/eBayISAPI.dll?ViewItem&item=1050807630">Star Wars: Boba Fett:When the fat lady Swings</A></FONT>
-</TD>
-<TD nowrap align="right" valign="top" width="11%"><FONT size=3><B><FONT size="-1" color="#666666">EUR</FONT> 5.50</B><BR><I>$4.95</I></FONT></TD></FONT></TD><TD align="center" valign="top" width="5%"><FONT size=3>-</FONT></TD><TD align="right" valign="top" width="18%"><FONT size=3>Dec-20 01:54</FONT></TD></TR></TABLE>
